"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var create_async_actions_1 = require("./create-async-actions");
test('creates a triad of identity action creators', function () {
    var _a = create_async_actions_1.default('foo'), start = _a[0], success = _a[1], fail = _a[2];
    expect(start.type).toBe('foo');
    expect(success.type).toBe('foo/SUCCESS');
    expect(fail.type).toBe('foo/ERROR');
    expect(start('foo')).toEqual({
        type: 'foo',
        payload: 'foo',
    });
    expect(success('foo')).toEqual({
        type: 'foo/SUCCESS',
        payload: 'foo',
    });
    var err = new Error('foo');
    expect(fail(err)).toEqual({
        type: 'foo/ERROR',
        payload: err,
        error: true,
    });
});
test('creates a triad of action creators with custom payloads', function () {
    var _a = create_async_actions_1.default('bar', function (str) { return str; }, function (length) { return length; }), start = _a[0], success = _a[1], fail = _a[2];
    expect(start.type).toBe('bar');
    expect(success.type).toBe('bar/SUCCESS');
    expect(fail.type).toBe('bar/ERROR');
    expect(start('bar')).toEqual({
        type: 'bar',
        payload: 'bar',
    });
    expect(success(3)).toEqual({
        type: 'bar/SUCCESS',
        payload: 3,
    });
    var err = new Error('foo');
    expect(fail(err)).toEqual({
        type: 'bar/ERROR',
        payload: err,
        error: true,
    });
});
test('allows for mixed void and any', function () {
    var _a = create_async_actions_1.default('baz', function () { }, function (users) { return users; }), start = _a[0], success = _a[1], fail = _a[2];
    expect(start()).toEqual({
        type: 'baz',
    });
    expect(success([{ name: 'knpwrs' }])).toEqual({
        type: 'baz/SUCCESS',
        payload: [{ name: 'knpwrs' }],
    });
    var err = new Error('baz');
    expect(fail(err)).toEqual({
        type: 'baz/ERROR',
        payload: err,
        error: true,
    });
});
//# sourceMappingURL=create-async-actions.test.js.map