"use strict";
/* eslint-disable no-param-reassign */
Object.defineProperty(exports, "__esModule", { value: true });
var handle_action_1 = require("./handle-action");
var create_action_1 = require("./create-action");
test('handles specific action', function () {
    var ac1 = create_action_1.default('foo1');
    var ac2 = create_action_1.default('bar1');
    var state = { counter: 0 };
    var re = handle_action_1.default(ac1, function (draft) {
        draft.counter += 1;
    }, state);
    var newState1 = re(state, ac1());
    expect(newState1).toEqual({ counter: 1 });
    expect(newState1).not.toBe(state);
    var newState2 = re(state, ac2());
    expect(newState2).toEqual({ counter: 0 });
    expect(newState2).toBe(state);
});
test('handles specific action with payload', function () {
    var ac1 = create_action_1.default('foo2');
    var ac2 = create_action_1.default('bar2');
    var state = { counter: 0 };
    var re = handle_action_1.default(ac1, function (draft, _a) {
        var payload = _a.payload;
        draft.counter += payload.num;
    }, state);
    var newState1 = re(state, ac1({ num: 10 }));
    expect(newState1).toEqual({ counter: 10 });
    expect(newState1).not.toBe(state);
    var newState2 = re(state, ac2({ num: 10 }));
    expect(newState2).toEqual({ counter: 0 });
    expect(newState2).toBe(state);
});
test('handles specific action with payload by returning value directly', function () {
    var ac1 = create_action_1.default('foo3');
    var state = { counter: 0 };
    var re = handle_action_1.default(ac1, function (draft, _a) {
        var payload = _a.payload;
        return ({
            counter: draft.counter + payload.num,
        });
    }, state);
    var newState1 = re(state, ac1({ num: 7 }));
    expect(newState1).toEqual({ counter: 7 });
    expect(newState1).not.toBe(state);
});
test('handles specific action with payload and ignores directly returned value if draft is mutated', function () {
    var ac1 = create_action_1.default('foo4');
    var state = { counter: 0 };
    var re = handle_action_1.default(ac1, function (draft, _a) {
        var payload = _a.payload;
        draft.counter += payload.num;
        return 'unintended return value';
    }, state);
    var newState1 = re(state, ac1({ num: 10 }));
    expect(newState1).toEqual({ counter: 10 });
    expect(newState1).not.toBe(state);
});
test('handles specific action and uses previous state if directly return value is undefined', function () {
    var ac1 = create_action_1.default('foo5');
    var state = { baz: 0 };
    var re = handle_action_1.default(ac1, function () { return undefined; }, state);
    var newState1 = re(state, ac1());
    expect(newState1).toEqual({ baz: 0 });
    expect(newState1).toBe(state);
});
test('supports default state', function () {
    var ac1 = create_action_1.default('foo6');
    var state = { baz: 0 };
    var re = handle_action_1.default(ac1, function () { return undefined; }, state);
    var newState1 = re(undefined, { type: '@@redux/INIT' });
    expect(newState1).toEqual({ baz: 0 });
    expect(newState1).toBe(state);
});
test('supports primitive state', function () {
    var ac1 = create_action_1.default('toUpperCase');
    var state = 'foobarbaz';
    var re = handle_action_1.default(ac1, function (s) { return s.toUpperCase(); }, state);
    var newState1 = re(state, ac1());
    expect(newState1).toBe('FOOBARBAZ');
});
//# sourceMappingURL=handle-action.test.js.map